@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2017-2023 Chupligin Sergey <neochapay@gmail.com>
+ * Copyright (C) 2017-2024 Chupligin Sergey <neochapay@gmail.com>
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Library General Public
@@ -21,8 +21,11 @@
 #define GLACIERAPP_H
 
 #include <QLocale>
+#include <QLoggingCategory>
 #include <QObject>
 
+Q_DECLARE_LOGGING_CATEGORY(lcGlacierAppCoreLog)
+
 class QGuiApplication;
 class QQmlApplicationEngine;
 class QQuickWindow;
